(nav content
&
{:keys [navtype stacked? tabdir] :or {navtype :tabs stacked false}})Creates a tab-pane with content out of a vector with maps of data. The structure has to be structured as follows:
Creates a tab-pane with content out of a vector with maps of data.
The structure has to be structured as follows:
* A top-level vector containing maps
* Each map has three keys:
** :type can be:
- :tabs/entry - this will create a top level entry
- :tabs/dropdown - this will assume the entries in the content key
** :title The text shown as the tab name
** :content If the :type is :tabs/entry, this contains the tab content. Can also be a zero-argument function.
If it's :tabs/dropdown, this contains the tab entries for the dropdown.
* The entries for :tabs/dropdown are structured exactly the same as the top-level entries.
Options: Takes a map with the keys navtype and/or stacked? and/or tabdir.
navtype takes either :tabs, :pills or :list.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |